==> config_export_json-8.x-1.0.tar.gz: config_export_json/src/Service/ConfigExportJsonApi.php <==
<?php

namespace Drupal\config_export_json\Service;

use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\File\FileSystemInterface;
use Drupal\locale\StringStorageInterface;
use Drupal\Core\StreamWrapper\PublicStream;
use Drupal\Component\Serialization\Json;

/**
 * ConfigExportJsonApi Service Class.
 */
class ConfigExportJsonApi {

  use StringTranslationTrait;

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  public $config;

  /**
   * The logger factory.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * The file system.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  private $fileSystem;

  /**
   * Storage for strings.
   *
   * @var \Drupal\locale\StringStorageInterface
   */
  private $storage;

  /**
   * Construct.
   */
  public function __construct(LanguageManagerInterface $language_manager, ConfigFactory $config_factory, LoggerChannelFactoryInterface $logger_factory, FileSystemInterface $file_system, StringStorageInterface $storage) {
    $this->languageManager = $language_manager;
    $this->config = $config_factory->getEditable('config_export_json.settings');
    $this->logger = $logger_factory->get('config_export_json');
    $this->fileSystem = $file_system;
    $this->storage = $storage;
  }

  /**
   * Method to add config to JSON.
   */
  public function add(array $projectConfigs) {

    foreach ($projectConfigs as $projectKey => $configs) {

      // Check if config already exists.
      if (!empty($this->config->get($projectKey))) {
        $currentConfig = $this->config->get($projectKey);
        $configs = array_merge($currentConfig, $configs);
      }

      $this->config->set($projectKey, $configs);
      $this->config->save();
    }

    return TRUE;
  }

  /**
   * Method to generate Json File.
   */
  public function exportJsonFile($log = NULL) {

    // Get JSON data to export.
    $json = $this->getJson();

    if (empty($json)) {
      $this->logger->error($this->t('Error on get JSON'));
      return FALSE;
    }

    // Get public folder.
    $publicPath = PublicStream::basePath();
    $path = $this->fileSystem->realpath($publicPath);
    $path .= '/config';

    // Create directory.
    $directory = file_prepare_directory($path, FILE_CREATE_DIRECTORY);

    // Check if directory was created.
    if (empty($directory)) {

      $this->logger->error($this->t('Error creating folder: @folder', [
        '@folder' => $path,
      ]));

      return FALSE;
    }

    // File name.
    $fileName = 'config.json';

    // Full path.
    $fullPath = $path . '/' . $fileName;

    // Delete old file.
    if (file_exists($fullPath)) {
      unlink($fullPath);
    }

    // Save the new file.
    $saved = file_put_contents($fullPath, $json);

    if (!$saved) {
      $this->logger->error($this->t('Error on export file'));
      return FALSE;
    }

    if ($log) {
      $this->logger->info($this->t('Json Config File has been exported. Path: @path', [
        '@path' => $fullPath,
      ]));
    }

    // Return file path.
    return $fullPath;
  }

  /**
   * Method to get JSON.
   */
  public function getJson() {

    $configs = $this->config->getRawData();

    if (empty($configs)) {
      return FALSE;
    }

    $json = Json::encode($configs, JSON_HEX_APOS | JSON_HEX_QUOT);

    return $json;
  }

}

==> config_export_json-8.x-1.1.tar.gz: config_export_json/src/Service/ConfigExportJsonApi.php <==
<?php

namespace Drupal\config_export_json\Service;

use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\File\FileSystemInterface;
use Drupal\locale\StringStorageInterface;
use Drupal\Core\StreamWrapper\PublicStream;
use Drupal\Component\Serialization\Json;
use Symfony\Component\Filesystem\Exception\IOExceptionInterface;
use Symfony\Component\Filesystem\Filesystem;

/**
 * ConfigExportJsonApi Service Class.
 */
class ConfigExportJsonApi {

  use StringTranslationTrait;

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  public $config;

  /**
   * The logger factory.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * The file system.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  private $fileSystem;

  /**
   * Storage for strings.
   *
   * @var \Drupal\locale\StringStorageInterface
   */
  private $storage;

  /**
   * Construct.
   */
  public function __construct(LanguageManagerInterface $language_manager, ConfigFactory $config_factory, LoggerChannelFactoryInterface $logger_factory, FileSystemInterface $file_system, StringStorageInterface $storage) {
    $this->languageManager = $language_manager;
    $this->config = $config_factory->getEditable('config_export_json.settings');
    $this->logger = $logger_factory->get('config_export_json');
    $this->fileSystem = $file_system;
    $this->storage = $storage;
  }

  /**
   * Method to add config to JSON.
   */
  public function add(array $projectConfigs) {

    foreach ($projectConfigs as $projectKey => $configs) {

      // Check if config already exists.
      if (!empty($this->config->get($projectKey))) {
        $currentConfig = $this->config->get($projectKey);
        $configs = array_merge($currentConfig, $configs);
      }

      $this->config->set($projectKey, $configs);
      $this->config->save();
    }

    return TRUE;
  }

  /**
   * Method to generate Json File.
   */
  public function exportJsonFile($log = NULL) {

    $filesystem = new Filesystem();

    // Get JSON data to export.
    $json = $this->getJson();

    if (empty($json)) {
      $this->logger->error($this->t('Error on get JSON'));
      return FALSE;
    }

    // Get public folder.
    $publicPath = PublicStream::basePath();
    $path = $this->fileSystem->realpath($publicPath);
    $path .= '/config';

    // Create directory if not exists.
    if (empty($filesystem->exists($path))) {

      // Check if directory was created.
      try {
        $filesystem->mkdir($path);
      }
      catch (IOExceptionInterface $exception) {

        $this->logger->error($this->t('Error creating folder: @folder', [
          '@folder' => $path,
        ]));

        return FALSE;
      }
    }

    // File name.
    $fileName = 'config.json';

    // Full path.
    $fullPath = $path . '/' . $fileName;

    // Delete old file.
    if ($filesystem->exists($fullPath)) {
      $filesystem->remove($fullPath);
    }

    // Save the new file.
    try {
      $filesystem->dumpFile($fullPath, $json);
    }
    catch (IOExceptionInterface $exception) {
      $this->logger->error($this->t('Error on export file'));
      return FALSE;
    }

    if ($log) {
      $this->logger->info($this->t('Json Config File has been exported. Path: @path', [
        '@path' => $fullPath,
      ]));
    }

    // Return file path.
    return $fullPath;
  }

  /**
   * Method to get JSON.
   */
  public function getJson() {

    $configs = $this->config->getRawData();

    if (empty($configs)) {
      return FALSE;
    }

    $json = Json::encode($configs, JSON_HEX_APOS | JSON_HEX_QUOT);

    return $json;
  }

}
